@@ -138,6 +138,8 @@ def ExternalSource(
     key_fields: FieldsType,
     value_fields: FieldsType,
     custom_json: Optional[str] = None,
+    factory_name: Optional[str] = None,
+    factory_params: Optional[Dict[str, str]] = None,
 ) -> api.ExternalSource:
     """
     External sources are online only data sources. During fetching, using
@@ -174,13 +176,23 @@ def ExternalSource(
                     ('field2', DataType.DOUBLE)
                 ))
             ]
+    :param factory_name: Optional name of the registered factory to use for
+        creating the external source handler.
+    :param factory_params: Optional parameters to pass to the factory when
+        creating the handler.
 
     """
     assert name != "contextual", "Please use `ContextualSource`"
+
+    factory_config = None
+    if factory_name is not None or factory_params is not None:
+        factory_config = api.ExternalSourceFactoryConfig(factoryName=factory_name, factoryParams=factory_params)
+
     return api.ExternalSource(
         metadata=api.MetaData(name=name, team=team, customJson=custom_json),
         keySchema=DataType.STRUCT(f"ext_{name}_keys", *key_fields),
         valueSchema=DataType.STRUCT(f"ext_{name}_values", *value_fields),
+        factoryConfig=factory_config,
     )
 
 
@@ -368,6 +380,25 @@ def BootstrapPart(
     return api.BootstrapPart(table=table, query=query, keyColumns=key_columns)
 
 
+def validate_left_source(source: api.Source) -> None:
+    """
+    Validate the left source of a Join, preventing user to create configs for a few unsupported scenarios.
+    """
+    # Validate left source is NOT an EventSource with isCumulative = True
+    if source.events:
+        if source.events.isCumulative:
+            raise ValueError(
+                "Using EventSource with isCumulative=True as Left source in Joins is NOT supported by Chronon now. "
+                "You can use either EntitySource or EventSource with isCumulative=False."
+            )
+    # Validate left source is NOT a JoinSource
+    if source.joinSource:
+        raise ValueError(
+            "Using JoinSource as Left source in Joins is NOT supported by Chronon now. "
+            "For offline-only use case, you can directly depend on the Join's output table."
+        )
+
+
 def Join(
     left: api.Source,
     right_parts: List[api.JoinPart],
@@ -501,6 +532,8 @@ def Join(
     :return:
         A join object that can be used to backfill or serve data. For ML use-cases this should map 1:1 to model.
     """
+    validate_left_source(left)
+
     # create a deep copy for case: multiple LeftOuterJoin use the same left,
     # validation will fail after the first iteration
     updated_left = copy.deepcopy(left)
